//HISTOGRAM OF THE PMF OF THE QUEUE LENGTH FOR THE TAXI STAND.
//POISSON ARRIVAL PROCESS WITH AN AVERAGE ARRIVAL RATE OF 0.85 ARRIVALS PER 
//TIME UNIT.


clc();

N=10000;                                            //Length of simulation

a=0.85;                                             //Arrival rate 

k=[0:10];

Poisson=zeros(size(k));                             //Calculate Poisson PMF

for m=k
    Poisson(m+1)=a.^m*exp(-a)./factorial(m);
end

queue(1)=0;                                         //Initial queue size

for n=1:N
    x=rand(1);
    arrivals=sum(x>cumsum(Poisson));                //Poisson RV
    departures=queue(n)>0;
    queue(n+1)=queue(n)+arrivals-departures;        //Current queue length
    
end

mean_queue_length=sum(queue)/length(queue)          //Compute average queue length 

bins=[0:25]

y=histplot(bins,queue);
PMF=y/N;                                            //Estimate PMF
bar(bins,PMF)                                       //Plot results

plot([min(bins)-1 max(bins)+1 0 1.1*max(PMF)])
ylabel('Probability Density Function','fontsize',2); 
xlabel('Queue Length','fontsize',2);

